@@ -5,7 +5,7 @@
 *	Created:  Sun Jan 24 20:36:39 PST 1999				      *
 *	Contents: DGPS over ip -- get RTCM signals from a remote tcp source   *
 *									      *
-*	$Id: dgpsip.c,v 1.45 2000/03/11 02:33:51 wolfgang Exp $
+*	$Id: dgpsip.c,v 1.49 2004/12/04 01:55:15 wolfgang Exp $
 ******************************************************************************/
 
 /*
@@ -302,7 +302,16 @@ main(int argc,
 	    while ((cnt = read(infd, buf, sizeof(buf))) > 0) {
 		if (dflag) {
 		    for (i = 0; i < cnt; i++) {
-			new_byte(buf[i]);
+			static int remhelo = 0;
+			if (!remhelo){
+			    putchar(buf[i]);
+			    if (buf[i] == '\n'){
+				remhelo=1;
+				putchar('\n');
+						    }
+			} else {
+			    new_byte(buf[i]);			    
+			}
 		    }
 		}
 		if (outfd >= 0) {
@@ -394,7 +403,7 @@ writesvfile(u_char * svtrackfile)
     if (binpgm) {
 	cnt = fwrite(sigpict, 1, sizeof(sigpict), svfile);
 	if (cnt != sizeof(sigpict)) {
-	    fprintf(stderr, "short write (%d/%d)\n",
+	    fprintf(stderr, "short write (%d/%zd)\n",
 		    cnt, sizeof(sigpict));
 	    fclose(svfile);
 	    return;
@@ -477,7 +486,7 @@ readsvfile(u_char * svtrackfile)
     if (bin) {
 	cnt = fread(sigpict, 1, sizeof(sigpict), svfile);
 	if (cnt != sizeof(sigpict)) {
-	    fprintf(stderr, "short read (%d/%d)\n",
+	    fprintf(stderr, "short read (%d/%zd)\n",
 		    cnt, sizeof(sigpict));
 	    fclose(svfile);
 	    return;
@@ -760,7 +769,7 @@ usage(void)
 }
 
 /* Are we missing ipv6 or vital libs? */
-#if !defined(HAVE_GETADDRINFO) || !defined(HAVE_NETINET6_IN6_H)
+#if !defined(HAVE_GETADDRINFO)
 
 int
 tcpopen(u_char * host,
@@ -824,7 +833,7 @@ tcpopen(u_char * host,
 	}
 	port = sp->s_port;
     }
-#ifndef SOCKADDR_IN_HAS_NO_SINLEN
+#ifdef HAVE_STRUCT_SOCKADDR_IN_SIN_LEN
     rem_sockaddr_in.sin_len = sizeof(rem_sockaddr_in);
 #endif
     rem_sockaddr_in.sin_family = AF_INET;
