@@ -5,7 +5,7 @@
 *	Created:  Thu Aug  1 19:12:42 PDT 1996				      *
 *	Contents: read nmea position sentences from the gps		      *
 *									      *
-*       $Id: nmea.c,v 1.15 1999/07/14 19:19:59 wolfgang Exp $
+*       $Id: nmea.c,v 1.16 2000/03/11 02:33:52 wolfgang Exp $
 ******************************************************************************/
 
 /*
@@ -224,11 +224,10 @@ extern int      verbose;
  *
  */
 
-struct nmeastate n;
+void            do_gga(u_char * nmeabuf, struct llpoint * point, struct nmeastate * n);
+void            do_gsv(u_char * nmeabuf, struct nmeastate * n);
 
-void            do_gga(u_char * nmeabuf, struct llpoint *point,
-		       struct nmeastate *n);
-void            do_gsv(u_char * nmeabuf, struct nmeastate *n);
+struct nmeastate n;
 
 int
 nmeaRead(u_char * nmeabuf,
@@ -307,27 +306,29 @@ do_gga(u_char * nmeabuf,
      */
 
     cp = strchr(nmeabuf, '*');
-    if (!cp) {
+    if (cp) {
+	cp++;
+	csum = strtol(cp, NULL, 16);
+
+	checksum = 0;
+	for (cp = nmeabuf + 1; *cp; cp++) {
+	    if (*cp == '*')	/* delimiter */
+		break;
+	    checksum ^= *cp;
+	}
+	if (checksum != csum) {
+	    if (verbose > 10)
+		fprintf(stderr,
+			"nmea: bad checksum exp 0x%x got 0x%x\n",
+			csum, checksum);
+	    return;
+	}
+    } else {
 	if (verbose > 10)
 	    fprintf(stderr, "GGA -- csum\n");
-	return;
+	/* return; */
     }
-    cp++;
-    csum = strtol(cp, NULL, 16);
 
-    checksum = 0;
-    for (cp = nmeabuf + 1; *cp; cp++) {
-	if (*cp == '*')		/* delimiter */
-	    break;
-	checksum ^= *cp;
-    }
-    if (checksum != csum) {
-	if (verbose > 10)
-	    fprintf(stderr,
-		    "nmea: bad checksum exp 0x%x got 0x%x\n",
-		    csum, checksum);
-	return;
-    }
     cp = ep = nmeabuf;
     ep = strchr(cp, ',');
     if (!ep) {
@@ -549,27 +550,29 @@ do_gsv(u_char * nmeabuf,
 	fprintf(stderr, "%s\n", nmeabuf);
 
     cp = strchr(nmeabuf, '*');
-    if (!cp) {
+    if (cp) {
+	cp++;
+	csum = strtol(cp, NULL, 16);
+
+	checksum = 0;
+	for (cp = nmeabuf + 1; *cp; cp++) {
+	    if (*cp == '*')	/* delimiter */
+		break;
+	    checksum ^= *cp;
+	}
+	if (checksum != csum) {
+	    if (verbose > 10)
+		fprintf(stderr,
+			"nmea: bad checksum exp 0x%x got 0x%x\n",
+			csum, checksum);
+	    return;
+	}
+    } else {
 	if (verbose > 10)
 	    fprintf(stderr, "GSV -- csum\n");
-	return;
+	/* return; */
     }
-    cp++;
-    csum = strtol(cp, NULL, 16);
 
-    checksum = 0;
-    for (cp = nmeabuf + 1; *cp; cp++) {
-	if (*cp == '*')		/* delimiter */
-	    break;
-	checksum ^= *cp;
-    }
-    if (checksum != csum) {
-	if (verbose > 10)
-	    fprintf(stderr,
-		    "nmea: bad checksum exp 0x%x got 0x%x\n",
-		    csum, checksum);
-	return;
-    }
     cp = ep = nmeabuf;
     ep = strchr(cp, ',');
     if (!ep) {
