@@ -1,4 +1,4 @@
-/* $Id: rtcm.c,v 1.11 1999/08/28 00:06:20 wolfgang Exp $  */
+/* $Id: rtcm.c,v 1.13 2004/12/03 21:04:43 wolfgang Exp $  */
 
 /* rtcm.c - decode RTCM SC-104 data from a DGPS beacon receiver */
 
@@ -535,7 +535,7 @@ new_frame(void)
   z_count = (message[1]>>17)&0x1fff;
   health = (message[1]>>6)&0x7;
   if (pfptr)
-    sprintf(s, "\tT\t%d", (pfptr-message)-2);
+    sprintf(s, "\tT\t%zd", (pfptr-message)-2);
   printf("H\t%d\t%d\t%.1f\t%d\t%d\t%d%s\n", msg_type, station_id,
 		(z_count*ZCOUNT_SCALE), seqno, msg_len, health,
 		(pfptr)?s:"");
@@ -634,8 +634,8 @@ fill_frame(void)
     msg_len = (data_word>>9)&0x1f;
 #ifdef DEBUG
     if (debug)
-	fprintf(stderr, "ff=%d: %08x %08x %d %d %d %d %s\n", frame_fill,
-		(u_int)fillptr,
+	fprintf(stderr, "ff=%d: %p %08x %d %d %d %d %s\n", frame_fill,
+		fillptr,
 	data_word, msg_len, word_count, pf_count, seqno, state_name[rtcm_state]);
 #endif
     if ((seqno < 0) || (((seqno +1) & 0x7) == seq))
@@ -649,8 +649,8 @@ fprintf(stderr,"2\n");
   else if (frame_fill > msg_len) { /* should be next preamble */
 #ifdef DEBUG
     if (debug)
-	fprintf(stderr, "ff=%d: %08x %08x %d %d %d %d %s\n", frame_fill,
-		(u_int)fillptr,
+	fprintf(stderr, "ff=%d: %p %08x %d %d %d %d %s\n", frame_fill,
+		fillptr,
 	data_word, msg_len, word_count, pf_count, seqno, state_name[rtcm_state]);
 #endif
     if (rtcm_state == FRAME_SYNCING) { /* be very tough */
@@ -676,8 +676,8 @@ fprintf(stderr,"2\n");
   else { /* other message words */
 #ifdef DEBUG
     if (debug)
-	fprintf(stderr, "ff=%d: %08x %08x %d %d %d %d %s\n", frame_fill,
-		(u_int)fillptr,
+	fprintf(stderr, "ff=%d: %p %08x %d %d %d %d %s\n", frame_fill,
+		fillptr,
 	data_word, msg_len, word_count, pf_count, seqno, state_name[rtcm_state]);
 #endif
     if (!data_word && !pfptr)
